@@ -1,5 +1,3 @@
-library(pins)
-library(plumber)
 skip_if_not_installed("ranger")
 
 set.seed(123)
@@ -38,8 +36,9 @@ test_that("can pin an ranger model", {
 
 test_that("default endpoint for ranger", {
     p <- pr() %>% vetiver_api(v)
-    expect_equal(names(p$routes), c("ping", "predict"))
-    expect_equal(map_chr(p$routes, "verbs"),
+    p_routes <- p$routes[-1]
+    expect_equal(names(p_routes), c("ping", "predict"))
+    expect_equal(map_chr(p_routes, "verbs"),
                  c(ping = "GET", predict = "POST"))
 })
 
